@@ -122,6 +122,9 @@ def get_stack_parameter_parser(istack):
     # for parameter in sorted(
     #    stack_parameters, key=lambda x: x['ParameterKey']):
     for p in sorted(istack.parameters):
+        # skip intrinsic cmd parameters already parsed
+        if hasattr(istack.cfg.cmd_args, p):
+            continue
         v = istack.parameters[p]
         allowed_values = v["AllowedValues"] if "AllowedValues" in v else []
         kwargs = {"type": str, "metavar": "\t%s" % v["Description"]}
@@ -170,7 +173,10 @@ def show_override(istack):
 
     out = pformat(params, width=istack.cfg.OUT_WIDTH)
 
-    istack.mylog(f"CURRENT NOT DEFAULT - STACK PARAMETERS\n{out}\n")
+    if istack.cfg.print_mylog:
+        istack.mylog(f"CURRENT NOT DEFAULT - STACK PARAMETERS\n{out}\n")
+
+    return params
 
 
 def process(istack, show=True):
