@@ -114,7 +114,8 @@ def get_show_parser(subparser, parents=[]):
     parser = subparser.add_parser("show", parents=parents, help="Show Stacks table")
 
     parser.add_argument(
-        "-F", "--fields", nargs="+", type=str, default=cfg.SHOW_TABLE_FIELDS
+        "-F", "--fields", nargs="+", type=str, default=cfg.SHOW_TABLE_FIELDS,
+        help="Can use syntax 'Name=DisplayName' to use custom table heading",
     )
     parser.add_argument(
         "-O", "--output", type=str, default="text", choices=["text", "html", "bare"]
@@ -386,6 +387,13 @@ def get_create_update_parser():
         "resources when an operation fails",
         action="store_true",
     )
+    parser.add_argument(
+        "--tags",
+        nargs="+",
+        help="Tags, space separated, to associate with this stack. Use syntax: Key=Value",
+        type=str,
+        default=[],
+    )
 
     return parser
 
@@ -640,4 +648,5 @@ def set_cfg(argv):
         parser.print_help()
         exit(0)
 
+    cfg.cmd_args = args[0]
     cfg.stack_args = args[1]
