@@ -57,9 +57,9 @@ def _process_template(istack):
 
             return r_root
 
-        elif isinstance(value, (int, str)):
+        elif isinstance(value, (int, str, float)):
 
-            return value
+            return str(value)
 
     def _resolve_sub(name, value):
         if isinstance(value, list):
