@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
 import sys
 from iboxstacksops.parser import set_cfg
-from iboxstacksops.common import IboxError
-from iboxstacksops.log import logger
+from iboxstacksops.common import IboxError, logger
 from iboxstacksops import cfg
 from iboxstacksops.msg import init as msg_init
 
